@@ -1,5 +1,5 @@
 package Text::ANSI::Tabs;
-our $VERSION = "0.08";
+our $VERSION = "1.01";
 
 =encoding utf-8
 
@@ -20,7 +20,7 @@ Text::ANSI::Tabs - Tab expand and unexpand with ANSI sequence
 
 =head1 VERSION
 
-Version 0.08
+Version 1.01
 
 =cut
 
@@ -190,8 +190,8 @@ See L<Text::ANSI::Fold> for detail.
 L<App::ansiexpand>,
 L<https://github.com/kaz-utashiro/App-ansiexpand>
 
-L<Text::ANSI::Fold::Tabs>,
-L<https://github.com/kaz-utashiro/Text-ANSI-Fold-Tabs>
+L<Text::ANSI::Tabs>,
+L<https://github.com/kaz-utashiro/Text-ANSI-Tabs>
 
 L<Text::ANSI::Fold::Util>,
 L<https://github.com/kaz-utashiro/Text-ANSI-Fold-Util>
